hepstats.modeling package
=========================

.. automodule:: hepstats.modeling
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   hepstats.modeling.bayesian_blocks
